---
title: <span class="badge object-type-disjunction"></span> MetricAggregationType
---
# <span class="badge object-type-disjunction"></span> MetricAggregationType

## Definition

```python
MetricAggregationType: typing.TypeAlias = typing.Union[typing.Literal["count"], elasticsearch.PipelineMetricAggregationType]
```
